pub type RestartCell = Rc<RefCell<Option<RestartRequest>>>;Expand description
Shared slot the debugger uses to hand a RestartRequest back to the
CLI’s re-solve loop.
Aliased Type
pub struct RestartCell { /* private fields */ }pub type RestartCell = Rc<RefCell<Option<RestartRequest>>>;Shared slot the debugger uses to hand a RestartRequest back to the
CLI’s re-solve loop.
pub struct RestartCell { /* private fields */ }