pub struct Archive {
pub xs: Vec<Vec<Number>>,
pub fs: Vec<Number>,
/* private fields */
}Expand description
Accepted minima plus the dedup test.
Fields
xs: Vec<Vec<Number>>fs: Vec<Number>Implementations
Sourceimpl Archive
impl Archive
pub fn new(dedup: Number, l: Vec<Number>) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn is_known(&self, x: &[Number]) -> bool
pub fn is_known(&self, x: &[Number]) -> bool
Is x within dedup of any already-accepted minimum?
Sourcepub fn near_any(&self, x: &[Number], radius: Number) -> bool
pub fn near_any(&self, x: &[Number], radius: Number) -> bool
Is x within radius of any accepted minimum (MLSL clustering)?
pub fn add(&mut self, x: Vec<Number>, f: Number)
Sourcepub fn order_by_objective(&self) -> Vec<usize>
pub fn order_by_objective(&self) -> Vec<usize>
Indices of the accepted minima ordered by ascending objective.